@@ -12,7 +12,8 @@
 
 RecentFilesModel::RecentFilesModel(QObject *parent)
     : QAbstractListModel(parent)
-{}
+{
+}
 
 QVariant RecentFilesModel::data(const QModelIndex &index, int role) const
 {
@@ -45,7 +46,7 @@ int RecentFilesModel::rowCount(const QModelIndex &parent) const
 
 void RecentFilesModel::refresh(const QList<QUrl> &urls)
 {
-    QVector<RecentFileInfo> recentFiles;
+    QList<RecentFileInfo> recentFiles;
     recentFiles.reserve(urls.count());
 
     QIcon icon;
