@@ -19,13 +19,7 @@ void TestHelper::startAndWaitForResult(KJob *job)
     eventLoop.exec(); // krazy:exclude=crashy
 }
 
-
 QStringList TestHelper::testFormats()
 {
-    return {
-        QStringLiteral("7z"),
-        QStringLiteral("rar"),
-        QStringLiteral("tar.bz2"),
-        QStringLiteral("zip")
-    };
+    return {QStringLiteral("7z"), QStringLiteral("rar"), QStringLiteral("tar.bz2"), QStringLiteral("zip")};
 }
