@@ -27,6 +27,17 @@ PluginManager::PluginManager(QObject *parent)
     loadPlugins();
 }
 
+Plugin *PluginManager::pluginById(const QString &pluginId) const
+{
+    const auto plugins = availablePlugins();
+    for (Plugin *plugin : plugins) {
+        if (plugin->metaData().pluginId() == pluginId) {
+            return plugin;
+        }
+    }
+    return nullptr;
+}
+
 QList<Plugin *> PluginManager::installedPlugins() const
 {
     return m_plugins;
@@ -260,7 +271,7 @@ bool PluginManager::libarchiveHasLzo()
     dependencyTool.start();
     dependencyTool.waitForFinished();
     const QString output = QString::fromUtf8(dependencyTool.readAllStandardOutput());
-    QRegularExpression regex(QStringLiteral("/.*/libarchive.so|/.*/libarchive.*.dylib"));
+    static const QRegularExpression regex(QStringLiteral("/.*/libarchive.so|/.*/libarchive.*.dylib"));
     if (!regex.match(output).hasMatch()) {
         return false;
     }
